@@ -5,28 +5,35 @@
 
 ##*## Methods for some of the generics in newGenerics.q for standard classes
 
+if (!exists("BIC", envir=asNamespace("stats"))) {
+BIC <-
+  ## Return the object's value of the Bayesian Information Criterion
+  function(object, ...) UseMethod("BIC")
+
 BIC.logLik <-
   ## BIC for logLik objects
   function(object, ...)
 {
-  -2 * (c(object) - attr(object, "df") * log(attr(object, "nobs"))/2)
+    no <- attr(object, "nobs")
+    if(is.null(no)) stop("no \"nobs\" attribute is available")
+    -2 * c(object) + attr(object, "df") * log(no)
 }
 
-BIC.lm <- BIC.nls <-
+BIC.default <-
   ## BIC for various fitted objects
   function(object, ...)
 {
-  if(nargs() > 1) {
-    object <- list(object, ...)
-    val <- lapply(object, logLik)
+  if(nargs() > 1L) {
+    val <- lapply(list(object, ...), logLik)
     val <-
       as.data.frame(t(sapply(val, function(el) c(attr(el, "df"), BIC(el)))))
     names(val) <- c("df", "BIC")
-    row.names(val) <- as.character(match.call()[-1])
+    row.names(val) <- as.character(match.call()[-1L])
     return(val)
   }
   BIC(logLik(object))
 }
+}
 
 Dim.default <- function(object, ...) dim(object)
 
@@ -679,6 +686,7 @@ print.compareFits <-
   function(x, ...)
 {			# Will need to be changed for S4!
   print(unclass(x), ...)
+  invisible(x)
 }
 
 print.correlation <-
