@@ -19,8 +19,6 @@
 
 ## Note that  require( stats )  has already happened ...
 
-BIC.lme <- BIC.lmList <- BIC.gls <- BIC.lm
-
 comparePred.lme <- comparePred.lmList <- comparePred.gls
 
 getData.nlme <- getData.gnls
@@ -38,3 +36,7 @@ residuals.gnls <- residuals.gls
 vcov.gls <- function (object, ...) object$varBeta
 
 vcov.lme <- function (object, ...) object$varFix
+
+.onUnload <- function(libpath)
+    library.dynam.unload("nlme", libpath)
+
